@@ -14,7 +14,7 @@ use List::Util qw( max min );
 use List::MoreUtils qw( all zip );
 use Array::Transpose;
 
-our $VERSION = '0.16';
+our $VERSION = '0.17';
 
 
 
@@ -117,17 +117,17 @@ sub saddlepoint
     my ($self) = @_;
 
     my $saddlepoint;
-    my $size = @{ $self->{payoff}[0] } - 1;
 
-    # Look for saddlepoints!
-    POINT:
-    for my $row ( 0 .. $size )
+    my $rsize = @{ $self->{payoff} } - 1;
+    my $csize = @{ $self->{payoff}[0] } - 1;
+
+    for my $row ( 0 .. $rsize )
     {
         # Get the minimum value of the current row
         my $min = min @{ $self->{payoff}[$row] };
 
         # Inspect each column given the row
-        for my $col ( 0 .. $size )
+        for my $col ( 0 .. $csize )
         {
             # Get the payoff
             my $val = $self->{payoff}[$row][$col];
@@ -137,7 +137,7 @@ sub saddlepoint
             {
                 # Gather the column values for each row
                 my @col;
-                for my $r ( 0 .. $size )
+                for my $r ( 0 .. $rsize )
                 {
                     push @col, $self->{payoff}[$r][$col];
                 }
@@ -147,8 +147,7 @@ sub saddlepoint
                 # Is the payoff also the column maximum?
                 if ( $val == $max )
                 {
-                    $saddlepoint = $val;
-                    last POINT;
+                    $saddlepoint->{"$row,$col"} = $val;
                 }
             }
         }
@@ -456,7 +455,7 @@ Game::Theory::TwoPersonMatrix - Analyze a 2 person matrix game
 
 =head1 VERSION
 
-version 0.16
+version 0.17
 
 =head1 SYNOPSIS
 
@@ -557,8 +556,7 @@ non-zero-sum game.
 
  $p = $g->saddlepoint;
 
-If the 2x2 zero-sum game is strictly determined, the saddlepoint is returned.
-Otherwise C<undef> is returned.
+Return the saddlepoint of a zero-sum game, or C<undef> if there is none.
 
 =head2 oddments()
 
